<?php

namespace App\Factory;

use App\Exception;

class BranchFactory {
    
    private $connection;
    
    public function __construct (\Doctrine\DBAL\Connection $connection) {
        $this->connection = $connection;
    }
    
    public function getStandardClient($branch) {
        $sql = "
            SELECT CDCLIENTE
              FROM PARAVEND
             WHERE CDFILIAL = :CDFILIAL";
            
        $params = [
            ":CDFILIAL" => $branch
        ];
        
        $stdClient = $this->connection->fetchAll($sql, $params)[0];
        
        if(empty($stdClient["CDCLIENTE"])) 
            throw new Exception\ParamsException("Cliente padrão não encontrado para a filial - $branch");
        
        return $stdClient;
    }
    
    public function getStandardConsumerType($branch) {
        $sql = "
            SELECT CDTIPOCONS, CDCCUSCLIE
              FROM PARAVEND
             WHERE CDFILIAL = :CDFILIAL";
            
        $params = [
            ":CDFILIAL" => $branch    
        ];
        
        $consumerT = $this->connection->fetchAll($sql, $params)[0];
        
        if(empty($consumerT["CDTIPOCONS"]))
            throw new Exception\ParamsException("Tipo de consumidor padrão não encontrado para a filial - $branch");
        
        if(empty($consumerT["CDCCUSCLIE"]))
            throw new Exception\ParamsException("Centro de custo do cliente não encontrado para a filial - $branch");
        
        return $consumerT;
    }
    
    public function getAddressInfo ($branch) {
        $sql = "
            SELECT CDMUNICIPIO, SGESTADO, DSENDEFILI, NRENDEFILISEP, NMBAIRFILI, NRCEPFILI
              FROM ENDEFILI
             WHERE CDFILIAL     = :CDFILIAL
               AND IDTPENDEFILI = 'P'";
        
        $params = [
            ":CDFILIAL" => $branch    
        ];
        
        return $this->connection->fetchAll($sql, $params)[0];
    }
   
   public function getCityName($sgEstado,$cdMunicipio){
       $sql = "
            SELECT NMMUNICIPIO
              FROM MUNICIPIO
             WHERE CDPAIS        = :CDPAIS 
               AND SGESTADO      = :SGESTADO
               AND CDMUNICIPIO   = :CDMUNICIPIO";
        
        $params = [
            ":CDPAIS"       =>  "0055",
            ":SGESTADO"     =>  $sgEstado,
            ":CDMUNICIPIO"  =>  $cdMunicipio
        ];
        return $this->connection->fetchAssoc($sql, $params);
   } 
   
   
    public function getBranchsNames() {
        $sql = "
            SELECT F.CDFILIAL, F.NMFILIAL, PV.CDVENDEDOR
                FROM FILIAL F
                    JOIN PARAVEND PV
                        ON PV.CDFILIAL = F.CDFILIAL
                    JOIN VENDEDOR V
                        ON V.CDVENDEDOR = PV.CDVENDEDOR
                        AND V.CDFILIAL = PV.CDFILIAL
            ORDER BY CDFILIAL
        ";
        
        return $this->connection->fetchAll($sql);
   } 
   
   public function getMenuBranches($menuId) {
        $sql = "
            SELECT T.CDFILIAL, F.NMFILIAL
              FROM FILITABGER T
              JOIN FILIAL F
                ON F.CDFILIAL = T.CDFILIAL
             WHERE T.CDTABEPREC = :CDTABEPREC
          ORDER BY F.CDFILIAL
        ";
        
        $params = [
            ":CDTABEPREC" => $menuId
        ];
        
        return $this->connection->fetchAll($sql, $params);
    } 
   
    public function getBranchData($cdFilial) {
        $sql = "
            SELECT 
                F.CDFILIAL,     /*Código da loja*/
                F.NMFILIAL,     /*Nome fantasia*/
                F.NMRAZSOCFILI, /*Razão Social*/
                F.NRINSJURFILI, /*CNPJ*/
                F.CDINSCESTA,   /*Insc. Estadual*/
                EF.DSENDEFILISEP,  /*Endereço*/
                EF.DSCOMPENDFIL,/*Complemento*/
                EF.NMBAIRFILI,  /*Bairro*/
                M.NMMUNICIPIO,  /*Cidade*/
                EF.SGESTADO,    /*UF*/
                EF.NRENDEFILISEP, /*Numero do Endereço*/
                EF.NRCEPFILI,     /*CEP da Filial*/
                EF.NMCONTFILI,  /*Nome do contato*/
                EF.NRTELEFILI,  /*telefone da loja*/
                EF.DSEMAILFILI, /*e-mail da loja*/
                TO_CHAR(F.DTINCLUSAO, 'DD/MM/YYYY') AS DTINCLUSAO,   /*Data inicial*/
                F.IDATIVO,       /*Ativa: Sim, Não*/
                V.CDCAIXA,
                C.CDLOJA
            FROM FILIAL F 
                JOIN ENDEFILI EF 
                    ON (F.CDFILIAL = EF.CDFILIAL)
                JOIN MUNICIPIO M
                    ON (EF.CDMUNICIPIO = M.CDMUNICIPIO)
                JOIN PARAVEND PV
                    ON PV.CDFILIAL = F.CDFILIAL
                JOIN VENDEDOR V
                    ON V.CDVENDEDOR = PV.CDVENDEDOR
                    AND V.CDFILIAL = PV.CDFILIAL
                JOIN CAIXA C
                    ON C.CDFILIAL = V.CDFILIAL
                    AND C.CDCAIXA = V.CDCAIXA
            WHERE (:CDFILIAL IS NULL OR F.CDFILIAL = :CDFILIAL)
            AND EF.IDTPENDEFILI	= 'P'
            ORDER BY CDFILIAL ASC
        ";
        
        $params = [
            ":CDFILIAL" => $cdFilial
        ];
        
        return $this->connection->fetchAll($sql, $params);
   }
   
   public function getHours($cdFilial, $cdLoja){
       
       $sql = "
           SELECT NRDIAATENDELOJA, HRINIATENDELOJA, HRFIMATENDELOJA 
             FROM ATENDELOJA 
                WHERE CDFILIAL = :CDFILIAL
                AND CDLOJA = :CDLOJA
                AND IDATENDELOJA = 'A'
                AND IDTPATENDELOJA = 'F'
            ORDER BY NRDIAATENDELOJA
       ";
       
       $params = [
            ':CDFILIAL' => $cdFilial,
            ':CDLOJA'   => $cdLoja
        ];
        
        return $this->connection->fetchAll($sql, $params);;
   }
   
   public function getPayments($cdFilial, $cdCaixa){
       
       $sql = "
           SELECT IT.DSBUTTON 
                FROM ITMENUCONFTE IT
             WHERE IT.NRCONFTELA = (SELECT NRCONFTELA	
                                        FROM CONFTELACAIXA	
                                      WHERE (CDFILIAL = :CDFILIAL OR CDFILICAIXA = :CDFILIAL)
                                        AND CDCAIXA = :CDCAIXA
                                        AND DTINIVIGENCIA <= SYSDATE)
             AND IT.IDTPBUTTON = '5'
       ";
       
       $params = [
            ':CDFILIAL' => $cdFilial,
            ':CDCAIXA'  => $cdCaixa
        ];
        
        return $this->connection->fetchAll($sql, $params);;
   }
   
   public function getBranchDetails($cdFilial){
       
       $sql = "
           SELECT PV.CDFILIAL, PV.CDVENDEDOR, PV.CDCLIENTE, CO.CDTIPOCONS, V.CDCAIXA, C.CDLOJA
              FROM PARAVEND PV
                JOIN VENDEDOR V
                    ON V.CDFILIAL = PV.CDFILIAL
                    AND V.CDVENDEDOR = PV.CDVENDEDOR
                JOIN CAIXA C
                    ON C.CDFILIAL = V.CDFILIAL
                    AND C.CDCAIXA = V.CDCAIXA
                JOIN CONSUMIDOR CO
                    ON CO.CDCLIENTE = PV.CDCLIENTE
                    AND CO.CDCONSUMIDOR = NVL(PV.CDCONSUMIDPADRAO, PV.CDCONSUMIDOR)
                WHERE PV.CDFILIAL = :CDFILIAL
       ";
       
       $params = [
            ':CDFILIAL' => $cdFilial
        ];
        
        $result = $this->connection->fetchAll($sql, $params);
        return $result[0];
   }
   
   public function getConftelaCaixa($cdFilial, $cdCaixa){
       
       $sql = "
            SELECT NRCONFTELA, CDFILIAL, CDFILICAIXA
              FROM CONFTELACAIXA	
                WHERE (CDFILIAL = :CDFILIAL OR CDFILICAIXA = :CDFILIAL)
                    AND CDCAIXA = :CDCAIXA
                    AND DTINIVIGENCIA <= SYSDATE
       ";
       
       $params = [
            ':CDFILIAL' => $cdFilial,
            ':CDCAIXA'  => $cdCaixa
        ];
        
        $result = $this->connection->fetchAll($sql, $params);
        return $result[0];
   }
}
